==> cueplot-0.0.2-src.tar.gz: cueplot-0.0.2-src/gui/opt/AxisTicsOptionWidget.h <==
/*
 * Cueplot: a GUI front end to gnuplot
 * Copyright (C) 2007 Muneyuki Noguchi
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, 
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef AXIS_TICS_OPTION_WIDGET_INCLUDED
#define AXIS_TICS_OPTION_WIDGET_INCLUDED

#include "AxisOptionWidget.h"

class AxisTics;

class QCheckBox;
class QComboBox;
class QGroupBox;
class QLineEdit;
class QRadioButton;
class QTabWidget;

class AxisTicsOptionWidget : public AxisOptionWidget
{
	Q_OBJECT

	public:
		AxisTicsOptionWidget(QWidget *parent = 0);
		~AxisTicsOptionWidget();

		void construct();

	private:
		// don't implement these
		AxisTicsOptionWidget(const AxisTicsOptionWidget &);
		AxisTicsOptionWidget &operator=(const AxisTicsOptionWidget &);

		void init();
		void apply();
		void constructWidget(QWidget *widget);
		void setOption(int axis);
		void setWidget(int axis);
		AxisTics *axisTics;
		QCheckBox *onCheckBox;
		QTabWidget *ticsTabWidget;
		QComboBox *locationComboBox;
		QCheckBox *mirrorCheckBox;
		QCheckBox *rotationCheckBox;
		QComboBox *positionComboBox;
		QLineEdit *startPosLineEdit;
		QLineEdit *incPosLineEdit;
		QLineEdit *endPosLineEdit;
		QLineEdit *labelsPosLineEdit;
		QGroupBox *posGroupBox;
};
#endif // AXIS_TICS_OPTION_WIDGET_INCLUDED

==> cueplot-0.0.3-src.tar.gz: cueplot-0.0.3-src/gui/opt/AxisTicsOptionWidget.h <==
/*
 * Cueplot: a GUI front-end to gnuplot
 * Copyright (C) 2007 Muneyuki Noguchi
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, 
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef AXIS_TICS_OPTION_WIDGET_INCLUDED
#define AXIS_TICS_OPTION_WIDGET_INCLUDED

#include "AxisOptionWidget.h"

class AxisTics;

class QCheckBox;
class QComboBox;
class QGroupBox;
class QLineEdit;
class QRadioButton;
class QTabWidget;

class AxisTicsOptionWidget : public AxisOptionWidget
{
	Q_OBJECT

	public:
		explicit AxisTicsOptionWidget(QWidget *parent = 0);
		~AxisTicsOptionWidget();

		void construct();

	private:
		// don't implement these
		AxisTicsOptionWidget(const AxisTicsOptionWidget &);
		AxisTicsOptionWidget &operator=(const AxisTicsOptionWidget &);

		void init();
		void apply();
		void constructWidget(QWidget *widget);
		void setOption(int axis);
		void setWidget(int axis);
		AxisTics *axisTics;
		QCheckBox *onCheckBox;
		QTabWidget *ticsTabWidget;
		QComboBox *locationComboBox;
		QCheckBox *mirrorCheckBox;
		QCheckBox *rotationCheckBox;
		QComboBox *positionComboBox;
		QLineEdit *startPosLineEdit;
		QLineEdit *incPosLineEdit;
		QLineEdit *endPosLineEdit;
		QLineEdit *labelsPosLineEdit;
		QGroupBox *posGroupBox;
};
#endif // AXIS_TICS_OPTION_WIDGET_INCLUDED
